About pypercolate
=================

.. only:: latex

   .. include:: about-include.rst

.. toctree::
   :maxdepth: 2

   License <license>

.. only:: not latex

   .. toctree::
      :maxdepth: 2

      Changelog <changelog>
